==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtcommonHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Qƃt@CɂsI"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "̓f[^̓˂킹鍀ږXg"
#define TKYC "Ŏw肵̓f[^̍ڂ-KŎw肳ꂽQƃf[^̍ڂsI"

/*-K*/
#define MKYT "Qƃf[^̓˂킹鍀ږrXg"
#define MKYC "Ŏw肵Qƃf[^̍ڂ-kŎw肳ꂽ̓f[^̍ڂsI"

/*-m*/
#define MSTT "Qƃt@C"
#define MSTC "Qƃt@Cw肷"

/*-r*/
#define REVT "]"
#define REVC "-RŎw肵sԍȊO̍sI"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-H*/
#define HAST "IHashɂIs"
#define HASC "Qƃf[^hashŊi[̓f[^IB̓f[^̍sAQƃf[^̍sȂA-k̍ڂŕוςĂȂƂ͏x̌オ]߂B"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵̓t@C̍ڒl-KŎw肵Qƃt@C̍ڒlrAl̓t@C̍sIB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcommon -k ڋq -m ref.xt -i dat.xt -o rsl.xt\n\
xtcommon -k ڋq -KӐ -m ref.xt -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtselstr,xtsel,xtjoin,xtnjoin"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/* DocBookauthorvf̌`œ͂                                        */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-sjis/xtcommonHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Qƃt@CɂsI"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "̓f[^̓˂킹鍀ږXg"
#define TKYC "Ŏw肵̓f[^̍ڂ-KŎw肳ꂽQƃf[^̍ڂsI"

/*-K*/
#define MKYT "Qƃf[^̓˂킹鍀ږrXg"
#define MKYC "Ŏw肵Qƃf[^̍ڂ-kŎw肳ꂽ̓f[^̍ڂsI"

/*-m*/
#define MSTT "Qƃt@C"
#define MSTC "Qƃt@Cw肷"

/*-r*/
#define REVT "]"
#define REVC "-RŎw肵sԍȊO̍sI"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-H*/
#define HAST "IHashɂIs"
#define HASC "Qƃf[^hashŊi[̓f[^IB̓f[^̍sAQƃf[^̍sȂA-k̍ڂŕוςĂȂƂ͏x̌オ]߂B"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵̓t@C̍ڒl-KŎw肵Qƃt@C̍ڒlrAl̓t@C̍sIB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcommon -k ڋq -m ref.xt -i dat.xt -o rsl.xt\n\
xtcommon -k ڋq -KӐ -m ref.xt -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtselstr,xtsel,xtjoin,xtnjoin"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/* DocBookauthorvf̌`œ͂                                        */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
